@@ -9,6 +9,9 @@ our $VERSION = "0.01";
 
 use Data::Dumper qw(Dumper);
 require Encode;
+
+# use base 'CommentOuted'; # will be ignored
+my $dummys = 1;      # use base 'CommentOuted'; # will be ignored
 use base 'Dummy';    # does not exist
 
 exit;
